@@ -610,8 +610,6 @@ class HubViewSet(viewsets.ModelViewSet):
     def get_queryset(self):
         return Hub.objects.all()
 
-
-
     def about(self, *args, **kwargs):
         api_about = {}
         api_about['isAPI'] = True
@@ -780,26 +778,29 @@ def signup(request):
         form = UserCreationForm()
     return render(request, 'registration/signup.html', {'form': form})
 
+
 def listHubHardware(request, hub_id):
     form_type = HardwareTypeForm(initial={'type': 'PiPico'})
     hardware_form = HardwarePiPicoForm(initial={'type': 'PiPico'})
     hardware = Hub.objects.get(pk=hub_id).hardware_set.all()
-    if request.accepted_renderer.format == 'html':
+    if request.accepts("text/html"):
         return Response({"form": hardware_form, "type_form": form_type, "hardwares": hardware},
                         template_name='hardwares.html')
 
     serialized_hardware = HardwareSerializer().to_json_array(hardware)
     return JsonResponse(serialized_hardware, status=200, safe=False)
 
+
 def listHubChannels(request, hub_id):
     channels = Hub.objects.get(pk=hub_id).channel_set.all()
     serialized_channels = ChannelSerializer(many=True).to_representation(channels)
     return JsonResponse(serialized_channels, status=200, safe=False)
 
+
 def listHubAccessories(request, hub_id):
     accessories = Hub.objects.get(pk=hub_id).accessory_set.all()
 
-    if request.accepted_renderer.format == 'html':
+    if request.accepts("text/html"):
         form = AccessoryForm()
         return Response({"form": form, "accessories": accessories}, template_name='accessories.html')
     serialized_accessories = AccessorySerializer(many=True).to_representation(accessories)
